@@ -2,7 +2,7 @@ use strict;
 
 package Path::Class::File;
 {
-  $Path::Class::File::VERSION = '0.29';
+  $Path::Class::File::VERSION = '0.31';
 }
 
 use Path::Class::Dir;
@@ -86,12 +86,29 @@ sub slurp {
   my $iomode = $args{iomode} || 'r';
   my $fh = $self->open($iomode) or croak "Can't read $self: $!";
 
-  if ($args{chomped} or $args{chomp}) {
-    chomp( my @data = <$fh> );
-    return wantarray ? @data : join '', @data;
+  if (wantarray) {
+    my @data = <$fh>;
+    chomp @data if $args{chomped} or $args{chomp};
+
+    if ( my $splitter = $args{split} ) {
+      @data = map { [ split $splitter, $_ ] } @data;
+    }
+
+    return @data;
   }
 
-  local $/ unless wantarray;
+
+  croak "'split' argument can only be used in list context"
+    if $args{split};
+
+
+  if ($args{chomped} or $args{chomp}) {
+    chomp( my @data = <$fh> );
+    return join '', @data;
+  }
+
+
+  local $/;
   return <$fh>;
 }
 
@@ -143,7 +160,7 @@ Path::Class::File - Objects representing files
 
 =head1 VERSION
 
-version 0.29
+version 0.31
 
 =head1 SYNOPSIS
 
@@ -367,14 +384,22 @@ the MODE argument of C<open()> is accepted here).  Just make sure it's
 a I<reading> mode.
 
   my @lines = $file->slurp(iomode => ':crlf');
-  my $lines = $file->slurp(iomode => '<:encoding(UTF−8)');
+  my $lines = $file->slurp(iomode => '<:encoding(UTF-8)');
 
 The default C<iomode> is C<r>.
 
+Lines can also be automatically splitted, mimicking the perl command-line
+option C<-a> by using the C<split> parameter. If this parameter is used,
+each line will be returned as an array ref.
+
+    my @lines = $file->slurp( chomp => 1, split => qr/\s*,\s*/ );
+
+The C<split> parameter can only be used in a list context.
+
 =item $file->spew( $content );
 
 The opposite of L</slurp>, this takes a list of strings and prints them
-to the file in write mode.  If the file can't be written too, this method
+to the file in write mode.  If the file can't be written to, this method
 will throw an exception.
 
 The content to be written can be either an array ref or a plain scalar.
